@@ -60,6 +60,10 @@ class CloudBuildAsyncClient:
     parse_build_path = staticmethod(CloudBuildClient.parse_build_path)
     build_trigger_path = staticmethod(CloudBuildClient.build_trigger_path)
     parse_build_trigger_path = staticmethod(CloudBuildClient.parse_build_trigger_path)
+    crypto_key_path = staticmethod(CloudBuildClient.crypto_key_path)
+    parse_crypto_key_path = staticmethod(CloudBuildClient.parse_crypto_key_path)
+    secret_version_path = staticmethod(CloudBuildClient.secret_version_path)
+    parse_secret_version_path = staticmethod(CloudBuildClient.parse_secret_version_path)
     service_account_path = staticmethod(CloudBuildClient.service_account_path)
     parse_service_account_path = staticmethod(
         CloudBuildClient.parse_service_account_path
@@ -234,6 +238,7 @@ class CloudBuildAsyncClient:
                    will be expanded when the build is created:
 
                    -  $PROJECT_ID: the project ID of the build.
+                   -  $PROJECT_NUMBER: the project number of the build.
                    -  $BUILD_ID: the autogenerated ID of the build.
                    -  $REPO_NAME: the source repository name specified
                       by RepoSource.
@@ -338,6 +343,7 @@ class CloudBuildAsyncClient:
                    will be expanded when the build is created:
 
                    -  $PROJECT_ID: the project ID of the build.
+                   -  $PROJECT_NUMBER: the project number of the build.
                    -  $BUILD_ID: the autogenerated ID of the build.
                    -  $REPO_NAME: the source repository name specified
                       by RepoSource.
@@ -382,6 +388,7 @@ class CloudBuildAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -468,6 +475,7 @@ class CloudBuildAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -530,6 +538,7 @@ class CloudBuildAsyncClient:
                    will be expanded when the build is created:
 
                    -  $PROJECT_ID: the project ID of the build.
+                   -  $PROJECT_NUMBER: the project number of the build.
                    -  $BUILD_ID: the autogenerated ID of the build.
                    -  $REPO_NAME: the source repository name specified
                       by RepoSource.
@@ -657,6 +666,7 @@ class CloudBuildAsyncClient:
                    will be expanded when the build is created:
 
                    -  $PROJECT_ID: the project ID of the build.
+                   -  $PROJECT_NUMBER: the project number of the build.
                    -  $BUILD_ID: the autogenerated ID of the build.
                    -  $REPO_NAME: the source repository name specified
                       by RepoSource.
@@ -867,6 +877,7 @@ class CloudBuildAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -946,6 +957,7 @@ class CloudBuildAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -1030,6 +1042,7 @@ class CloudBuildAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -1154,9 +1167,7 @@ class CloudBuildAsyncClient:
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             source (:class:`google.cloud.devtools.cloudbuild_v1.types.RepoSource`):
-                Required. Source to build against
-                this trigger.
-
+                Source to build against this trigger.
                 This corresponds to the ``source`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1184,6 +1195,7 @@ class CloudBuildAsyncClient:
                    will be expanded when the build is created:
 
                    -  $PROJECT_ID: the project ID of the build.
+                   -  $PROJECT_NUMBER: the project number of the build.
                    -  $BUILD_ID: the autogenerated ID of the build.
                    -  $REPO_NAME: the source repository name specified
                       by RepoSource.
@@ -1241,6 +1253,53 @@ class CloudBuildAsyncClient:
         # Done; return the response.
         return response
 
+    async def receive_trigger_webhook(
+        self,
+        request: cloudbuild.ReceiveTriggerWebhookRequest = None,
+        *,
+        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> cloudbuild.ReceiveTriggerWebhookResponse:
+        r"""ReceiveTriggerWebhook [Experimental] is called when the API
+        receives a webhook request targeted at a specific trigger.
+
+        Args:
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.ReceiveTriggerWebhookRequest`):
+                The request object. ReceiveTriggerWebhookRequest
+                [Experimental] is the request object accepted by the
+                ReceiveTriggerWebhook method.
+
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.devtools.cloudbuild_v1.types.ReceiveTriggerWebhookResponse:
+                ReceiveTriggerWebhookResponse [Experimental] is the response object for the
+                   ReceiveTriggerWebhook method.
+
+        """
+        # Create or coerce a protobuf request object.
+
+        request = cloudbuild.ReceiveTriggerWebhookRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.receive_trigger_webhook,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
     async def create_worker_pool(
         self,
         request: cloudbuild.CreateWorkerPoolRequest = None,
@@ -1353,6 +1412,7 @@ class CloudBuildAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -1500,6 +1560,7 @@ class CloudBuildAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
