@@ -189,6 +189,38 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/triggers/(?P<trigger>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def crypto_key_path(project: str, location: str, keyring: str, key: str,) -> str:
+        """Return a fully-qualified crypto_key string."""
+        return "projects/{project}/locations/{location}/keyRings/{keyring}/cryptoKeys/{key}".format(
+            project=project, location=location, keyring=keyring, key=key,
+        )
+
+    @staticmethod
+    def parse_crypto_key_path(path: str) -> Dict[str, str]:
+        """Parse a crypto_key path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/keyRings/(?P<keyring>.+?)/cryptoKeys/(?P<key>.+?)$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def secret_version_path(project: str, secret: str, version: str,) -> str:
+        """Return a fully-qualified secret_version string."""
+        return "projects/{project}/secrets/{secret}/versions/{version}".format(
+            project=project, secret=secret, version=version,
+        )
+
+    @staticmethod
+    def parse_secret_version_path(path: str) -> Dict[str, str]:
+        """Parse a secret_version path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/secrets/(?P<secret>.+?)/versions/(?P<version>.+?)$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
     @staticmethod
     def service_account_path(project: str, service_account: str,) -> str:
         """Return a fully-qualified service_account string."""
@@ -430,6 +462,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                    will be expanded when the build is created:
 
                    -  $PROJECT_ID: the project ID of the build.
+                   -  $PROJECT_NUMBER: the project number of the build.
                    -  $BUILD_ID: the autogenerated ID of the build.
                    -  $REPO_NAME: the source repository name specified
                       by RepoSource.
@@ -535,6 +568,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                    will be expanded when the build is created:
 
                    -  $PROJECT_ID: the project ID of the build.
+                   -  $PROJECT_NUMBER: the project number of the build.
                    -  $BUILD_ID: the autogenerated ID of the build.
                    -  $REPO_NAME: the source repository name specified
                       by RepoSource.
@@ -713,6 +747,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                    will be expanded when the build is created:
 
                    -  $PROJECT_ID: the project ID of the build.
+                   -  $PROJECT_NUMBER: the project number of the build.
                    -  $BUILD_ID: the autogenerated ID of the build.
                    -  $REPO_NAME: the source repository name specified
                       by RepoSource.
@@ -841,6 +876,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                    will be expanded when the build is created:
 
                    -  $PROJECT_ID: the project ID of the build.
+                   -  $PROJECT_NUMBER: the project number of the build.
                    -  $BUILD_ID: the autogenerated ID of the build.
                    -  $REPO_NAME: the source repository name specified
                       by RepoSource.
@@ -1320,9 +1356,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             source (google.cloud.devtools.cloudbuild_v1.types.RepoSource):
-                Required. Source to build against
-                this trigger.
-
+                Source to build against this trigger.
                 This corresponds to the ``source`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1350,6 +1384,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                    will be expanded when the build is created:
 
                    -  $PROJECT_ID: the project ID of the build.
+                   -  $PROJECT_NUMBER: the project number of the build.
                    -  $BUILD_ID: the autogenerated ID of the build.
                    -  $REPO_NAME: the source repository name specified
                       by RepoSource.
@@ -1408,6 +1443,54 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # Done; return the response.
         return response
 
+    def receive_trigger_webhook(
+        self,
+        request: cloudbuild.ReceiveTriggerWebhookRequest = None,
+        *,
+        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> cloudbuild.ReceiveTriggerWebhookResponse:
+        r"""ReceiveTriggerWebhook [Experimental] is called when the API
+        receives a webhook request targeted at a specific trigger.
+
+        Args:
+            request (google.cloud.devtools.cloudbuild_v1.types.ReceiveTriggerWebhookRequest):
+                The request object. ReceiveTriggerWebhookRequest
+                [Experimental] is the request object accepted by the
+                ReceiveTriggerWebhook method.
+
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.devtools.cloudbuild_v1.types.ReceiveTriggerWebhookResponse:
+                ReceiveTriggerWebhookResponse [Experimental] is the response object for the
+                   ReceiveTriggerWebhook method.
+
+        """
+        # Create or coerce a protobuf request object.
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a cloudbuild.ReceiveTriggerWebhookRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, cloudbuild.ReceiveTriggerWebhookRequest):
+            request = cloudbuild.ReceiveTriggerWebhookRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.receive_trigger_webhook]
+
+        # Send the request.
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
     def create_worker_pool(
         self,
         request: cloudbuild.CreateWorkerPoolRequest = None,
