@@ -16,93 +16,103 @@
 #
 
 from .cloudbuild import (
-    RetryBuildRequest,
-    RunBuildTriggerRequest,
-    StorageSource,
-    RepoSource,
-    Source,
-    BuiltImage,
-    BuildStep,
-    Volume,
-    Results,
     ArtifactResult,
-    Build,
     Artifacts,
-    TimeSpan,
+    Build,
     BuildOperationMetadata,
-    SourceProvenance,
-    FileHashes,
-    Hash,
-    Secret,
+    BuildOptions,
+    BuildStep,
+    BuildTrigger,
+    BuiltImage,
+    CancelBuildRequest,
     CreateBuildRequest,
+    CreateBuildTriggerRequest,
+    CreateWorkerPoolRequest,
+    DeleteBuildTriggerRequest,
+    DeleteWorkerPoolRequest,
+    FileHashes,
     GetBuildRequest,
+    GetBuildTriggerRequest,
+    GetWorkerPoolRequest,
+    GitHubEventsConfig,
+    Hash,
+    InlineSecret,
     ListBuildsRequest,
     ListBuildsResponse,
-    CancelBuildRequest,
-    BuildTrigger,
-    GitHubEventsConfig,
-    PullRequestFilter,
-    PushFilter,
-    CreateBuildTriggerRequest,
-    GetBuildTriggerRequest,
     ListBuildTriggersRequest,
     ListBuildTriggersResponse,
-    DeleteBuildTriggerRequest,
-    UpdateBuildTriggerRequest,
-    BuildOptions,
-    WorkerPool,
-    WorkerConfig,
-    Network,
-    CreateWorkerPoolRequest,
-    GetWorkerPoolRequest,
-    DeleteWorkerPoolRequest,
-    UpdateWorkerPoolRequest,
     ListWorkerPoolsRequest,
     ListWorkerPoolsResponse,
+    Network,
+    PullRequestFilter,
+    PushFilter,
+    ReceiveTriggerWebhookRequest,
+    ReceiveTriggerWebhookResponse,
+    RepoSource,
+    Results,
+    RetryBuildRequest,
+    RunBuildTriggerRequest,
+    Secret,
+    SecretManagerSecret,
+    Secrets,
+    Source,
+    SourceProvenance,
+    StorageSource,
+    TimeSpan,
+    UpdateBuildTriggerRequest,
+    UpdateWorkerPoolRequest,
+    Volume,
+    WorkerConfig,
+    WorkerPool,
 )
 
 __all__ = (
-    "RetryBuildRequest",
-    "RunBuildTriggerRequest",
-    "StorageSource",
-    "RepoSource",
-    "Source",
-    "BuiltImage",
-    "BuildStep",
-    "Volume",
-    "Results",
     "ArtifactResult",
-    "Build",
     "Artifacts",
-    "TimeSpan",
+    "Build",
     "BuildOperationMetadata",
-    "SourceProvenance",
-    "FileHashes",
-    "Hash",
-    "Secret",
+    "BuildOptions",
+    "BuildStep",
+    "BuildTrigger",
+    "BuiltImage",
+    "CancelBuildRequest",
     "CreateBuildRequest",
+    "CreateBuildTriggerRequest",
+    "CreateWorkerPoolRequest",
+    "DeleteBuildTriggerRequest",
+    "DeleteWorkerPoolRequest",
+    "FileHashes",
     "GetBuildRequest",
+    "GetBuildTriggerRequest",
+    "GetWorkerPoolRequest",
+    "GitHubEventsConfig",
+    "Hash",
+    "InlineSecret",
     "ListBuildsRequest",
     "ListBuildsResponse",
-    "CancelBuildRequest",
-    "BuildTrigger",
-    "GitHubEventsConfig",
-    "PullRequestFilter",
-    "PushFilter",
-    "CreateBuildTriggerRequest",
-    "GetBuildTriggerRequest",
     "ListBuildTriggersRequest",
     "ListBuildTriggersResponse",
-    "DeleteBuildTriggerRequest",
-    "UpdateBuildTriggerRequest",
-    "BuildOptions",
-    "WorkerPool",
-    "WorkerConfig",
-    "Network",
-    "CreateWorkerPoolRequest",
-    "GetWorkerPoolRequest",
-    "DeleteWorkerPoolRequest",
-    "UpdateWorkerPoolRequest",
     "ListWorkerPoolsRequest",
     "ListWorkerPoolsResponse",
+    "Network",
+    "PullRequestFilter",
+    "PushFilter",
+    "ReceiveTriggerWebhookRequest",
+    "ReceiveTriggerWebhookResponse",
+    "RepoSource",
+    "Results",
+    "RetryBuildRequest",
+    "RunBuildTriggerRequest",
+    "Secret",
+    "SecretManagerSecret",
+    "Secrets",
+    "Source",
+    "SourceProvenance",
+    "StorageSource",
+    "TimeSpan",
+    "UpdateBuildTriggerRequest",
+    "UpdateWorkerPoolRequest",
+    "Volume",
+    "WorkerConfig",
+    "WorkerPool",
 )
