@@ -18,6 +18,7 @@
 import proto  # type: ignore
 
 
+from google.api import httpbody_pb2 as httpbody  # type: ignore
 from google.protobuf import duration_pb2 as duration  # type: ignore
 from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
 
@@ -42,6 +43,9 @@ __protobuf__ = proto.module(
         "SourceProvenance",
         "FileHashes",
         "Hash",
+        "Secrets",
+        "InlineSecret",
+        "SecretManagerSecret",
         "Secret",
         "CreateBuildRequest",
         "GetBuildRequest",
@@ -59,6 +63,8 @@ __protobuf__ = proto.module(
         "DeleteBuildTriggerRequest",
         "UpdateBuildTriggerRequest",
         "BuildOptions",
+        "ReceiveTriggerWebhookRequest",
+        "ReceiveTriggerWebhookResponse",
         "WorkerPool",
         "WorkerConfig",
         "Network",
@@ -101,8 +107,7 @@ class RunBuildTriggerRequest(proto.Message):
         trigger_id (str):
             Required. ID of the trigger.
         source (google.cloud.devtools.cloudbuild_v1.types.RepoSource):
-            Required. Source to build against this
-            trigger.
+            Source to build against this trigger.
     """
 
     project_id = proto.Field(proto.STRING, number=1)
@@ -148,8 +153,7 @@ class RepoSource(proto.Message):
             Repository. If omitted, the project ID
             requesting the build is assumed.
         repo_name (str):
-            Required. Name of the Cloud Source
-            Repository.
+            Name of the Cloud Source Repository.
         branch_name (str):
             Regex matching branches to build.
             The syntax of the regular expressions accepted
@@ -454,6 +458,7 @@ class Build(proto.Message):
     when the build is created:
 
     -  $PROJECT_ID: the project ID of the build.
+    -  $PROJECT_NUMBER: the project number of the build.
     -  $BUILD_ID: the autogenerated ID of the build.
     -  $REPO_NAME: the source repository name specified by RepoSource.
     -  $BRANCH_NAME: the branch name specified by RepoSource.
@@ -550,8 +555,12 @@ class Build(proto.Message):
             Tags for annotation of a ``Build``. These are not docker
             tags.
         secrets (Sequence[google.cloud.devtools.cloudbuild_v1.types.Secret]):
-            Secrets to decrypt using Cloud Key Management
-            Service.
+            Secrets to decrypt using Cloud Key Management Service. Note:
+            Secret Manager is the recommended technique for managing
+            sensitive data with Cloud Build. Use ``available_secrets``
+            to configure builds to access secrets from Secret Manager.
+            For instructions, see:
+            https://cloud.google.com/cloud-build/docs/securing-builds/use-secrets
         timing (Sequence[google.cloud.devtools.cloudbuild_v1.types.Build.TimingEntry]):
             Output only. Stores timing information for phases of the
             build. Valid keys are:
@@ -568,7 +577,9 @@ class Build(proto.Message):
             ``projects/{PROJECT_ID}/serviceAccounts/{ACCOUNT}``. ACCOUNT
             can be email address or uniqueId of the service account.
 
-            This field is in alpha and is not publicly available.
+            This field is in beta.
+        available_secrets (google.cloud.devtools.cloudbuild_v1.types.Secrets):
+            Secrets and secret environment variables.
     """
 
     class Status(proto.Enum):
@@ -635,6 +646,8 @@ class Build(proto.Message):
 
     service_account = proto.Field(proto.STRING, number=42)
 
+    available_secrets = proto.Field(proto.MESSAGE, number=47, message="Secrets",)
+
 
 class Artifacts(proto.Message):
     r"""Artifacts produced by a build that should be uploaded upon
@@ -797,11 +810,77 @@ class Hash(proto.Message):
     value = proto.Field(proto.BYTES, number=2)
 
 
-class Secret(proto.Message):
-    r"""Pairs a set of secret environment variables containing
+class Secrets(proto.Message):
+    r"""Secrets and secret environment variables.
+
+    Attributes:
+        secret_manager (Sequence[google.cloud.devtools.cloudbuild_v1.types.SecretManagerSecret]):
+            Secrets in Secret Manager and associated
+            secret environment variable.
+        inline (Sequence[google.cloud.devtools.cloudbuild_v1.types.InlineSecret]):
+            Secrets encrypted with KMS key and the
+            associated secret environment variable.
+    """
+
+    secret_manager = proto.RepeatedField(
+        proto.MESSAGE, number=1, message="SecretManagerSecret",
+    )
+
+    inline = proto.RepeatedField(proto.MESSAGE, number=2, message="InlineSecret",)
+
+
+class InlineSecret(proto.Message):
+    r"""Pairs a set of secret environment variables mapped to
     encrypted values with the Cloud KMS key to use to decrypt the
     value.
 
+    Attributes:
+        kms_key_name (str):
+            Resource name of Cloud KMS crypto key to decrypt the
+            encrypted value. In format:
+            projects/\ */locations/*/keyRings/*/cryptoKeys/*
+        env_map (Sequence[google.cloud.devtools.cloudbuild_v1.types.InlineSecret.EnvMapEntry]):
+            Map of environment variable name to its
+            encrypted value.
+            Secret environment variables must be unique
+            across all of a build's secrets, and must be
+            used by at least one build step. Values can be
+            at most 64 KB in size. There can be at most 100
+            secret values across all of a build's secrets.
+    """
+
+    kms_key_name = proto.Field(proto.STRING, number=1)
+
+    env_map = proto.MapField(proto.STRING, proto.BYTES, number=2)
+
+
+class SecretManagerSecret(proto.Message):
+    r"""Pairs a secret environment variable with a SecretVersion in
+    Secret Manager.
+
+    Attributes:
+        version_name (str):
+            Resource name of the SecretVersion. In format:
+            projects/\ */secrets/*/versions/\*
+        env (str):
+            Environment variable name to associate with
+            the secret. Secret environment variables must be
+            unique across all of a build's secrets, and must
+            be used by at least one build step.
+    """
+
+    version_name = proto.Field(proto.STRING, number=1)
+
+    env = proto.Field(proto.STRING, number=2)
+
+
+class Secret(proto.Message):
+    r"""Pairs a set of secret environment variables containing encrypted
+    values with the Cloud KMS key to use to decrypt the value. Note: Use
+    ``kmsKeyName`` with ``available_secrets`` instead of using
+    ``kmsKeyName`` with ``secret``. For instructions see:
+    https://cloud.google.com/cloud-build/docs/securing-builds/use-encrypted-credentials.
+
     Attributes:
         kms_key_name (str):
             Cloud KMS key name to use to decrypt these
@@ -873,8 +952,16 @@ class ListBuildsRequest(proto.Message):
         page_size (int):
             Number of results to return in the list.
         page_token (str):
-            Token to provide to skip to a particular spot
-            in the list.
+            The page token for the next page of Builds.
+
+            If unspecified, the first page of results is returned.
+
+            If the token is rejected for any reason, INVALID_ARGUMENT
+            will be thrown. In this case, the token should be discarded,
+            and pagination should be restarted from the first page of
+            results.
+
+            See https://google.aip.dev/158 for more.
         filter (str):
             The raw filter text to constrain the results.
     """
@@ -898,6 +985,8 @@ class ListBuildsResponse(proto.Message):
             Builds will be sorted by ``create_time``, descending.
         next_page_token (str):
             Token to receive the next page of results.
+            This will be absent if the end of the response
+            list has been reached.
     """
 
     @property
@@ -914,7 +1003,7 @@ class CancelBuildRequest(proto.Message):
 
     Attributes:
         name (str):
-            The name of the ``Build`` to retrieve. Format:
+            The name of the ``Build`` to cancel. Format:
             ``projects/{project}/locations/{location}/builds/{build}``
         project_id (str):
             Required. ID of the project.
@@ -966,8 +1055,8 @@ class BuildTrigger(proto.Message):
         build (google.cloud.devtools.cloudbuild_v1.types.Build):
             Contents of the build template.
         filename (str):
-            Path, from the source root, to a file whose
-            contents is used for the template.
+            Path, from the source root, to the build
+            configuration file (i.e. cloudbuild.yaml).
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. Time when the trigger was
             created.
@@ -1091,6 +1180,7 @@ class PullRequestFilter(proto.Message):
         r"""Controls behavior of Pull Request comments."""
         COMMENTS_DISABLED = 0
         COMMENTS_ENABLED = 1
+        COMMENTS_ENABLED_FOR_EXTERNAL_CONTRIBUTORS_ONLY = 2
 
     branch = proto.Field(proto.STRING, number=2, oneof="git_ref")
 
@@ -1324,6 +1414,8 @@ class BuildOptions(proto.Message):
         UNSPECIFIED = 0
         N1_HIGHCPU_8 = 1
         N1_HIGHCPU_32 = 2
+        E2_HIGHCPU_8 = 5
+        E2_HIGHCPU_32 = 6
 
     class SubstitutionOption(proto.Enum):
         r"""Specifies the behavior when there is an error in the
@@ -1376,6 +1468,38 @@ class BuildOptions(proto.Message):
     volumes = proto.RepeatedField(proto.MESSAGE, number=14, message="Volume",)
 
 
+class ReceiveTriggerWebhookRequest(proto.Message):
+    r"""ReceiveTriggerWebhookRequest [Experimental] is the request object
+    accepted by the ReceiveTriggerWebhook method.
+
+    Attributes:
+        body (google.api.httpbody_pb2.HttpBody):
+            HTTP request body.
+        project_id (str):
+            Project in which the specified trigger lives
+        trigger (str):
+            Name of the trigger to run the payload
+            against
+        secret (str):
+            Secret token used for authorization if an
+            OAuth token isn't provided.
+    """
+
+    body = proto.Field(proto.MESSAGE, number=1, message=httpbody.HttpBody,)
+
+    project_id = proto.Field(proto.STRING, number=2)
+
+    trigger = proto.Field(proto.STRING, number=3)
+
+    secret = proto.Field(proto.STRING, number=4)
+
+
+class ReceiveTriggerWebhookResponse(proto.Message):
+    r"""ReceiveTriggerWebhookResponse [Experimental] is the response object
+    for the ReceiveTriggerWebhook method.
+    """
+
+
 class WorkerPool(proto.Message):
     r"""Configuration for a WorkerPool to run the builds.
     Workers are machines that Cloud Build uses to run your builds.
